# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.indonesia_nik_input import IndonesiaNikInput

class TestIndonesiaNikInput(unittest.TestCase):
    """IndonesiaNikInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IndonesiaNikInput:
        """Test IndonesiaNikInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IndonesiaNikInput`
        """
        model = IndonesiaNikInput()
        if include_optional:
            return IndonesiaNikInput(
                full_name = '0',
                date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                nik_id_number = '48072888001528021798090123456789101112131415'
            )
        else:
            return IndonesiaNikInput(
                full_name = '0',
                date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                nik_id_number = '48072888001528021798090123456789101112131415',
        )
        """

    def testIndonesiaNikInput(self):
        """Test IndonesiaNikInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
