# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.document_data import DocumentData

class TestDocumentData(unittest.TestCase):
    """DocumentData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DocumentData:
        """Test DocumentData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DocumentData`
        """
        model = DocumentData()
        if include_optional:
            return DocumentData(
                type = 'Passport',
                number = '',
                issue_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                expiration_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                issuing_country = '',
                issuing_authority = ''
            )
        else:
            return DocumentData(
        )
        """

    def testDocumentData(self):
        """Test DocumentData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
