# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.http_validation_problem_details import HttpValidationProblemDetails

class TestHttpValidationProblemDetails(unittest.TestCase):
    """HttpValidationProblemDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> HttpValidationProblemDetails:
        """Test HttpValidationProblemDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `HttpValidationProblemDetails`
        """
        model = HttpValidationProblemDetails()
        if include_optional:
            return HttpValidationProblemDetails(
                type = '',
                title = '',
                status = 56,
                detail = '',
                instance = '',
                errors = {
                    'key' : [
                        ''
                        ]
                    }
            )
        else:
            return HttpValidationProblemDetails(
        )
        """

    def testHttpValidationProblemDetails(self):
        """Test HttpValidationProblemDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
