# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SessionErrorCode(str, Enum):
    """
    SessionErrorCode
    """

    """
    allowed enum values
    """
    INTERNAL = 'Internal'
    OTHER = 'Other'
    CANCELED = 'Canceled'
    USERABANDONED = 'UserAbandoned'
    USERTIMEDOUT = 'UserTimedOut'
    EXPIRED = 'Expired'
    INVALIDIMAGE = 'InvalidImage'
    INAUTHENTIC = 'Inauthentic'
    UNSUPPORTEDDOCUMENT = 'UnsupportedDocument'
    ASSURANCELEVELNOTMET = 'AssuranceLevelNotMet'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SessionErrorCode from a JSON string"""
        return cls(json.loads(json_str))


