# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.list_provider_contracts_response import ListProviderContractsResponse

class TestListProviderContractsResponse(unittest.TestCase):
    """ListProviderContractsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListProviderContractsResponse:
        """Test ListProviderContractsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListProviderContractsResponse`
        """
        model = ListProviderContractsResponse()
        if include_optional:
            return ListProviderContractsResponse(
                provider_contracts = [
                    trinsic_api.models.provider_contract.ProviderContract(
                        id = 'usa-california-dmv', 
                        name = 'CA DMV', 
                        subtext = 'dmv.ca.gov', 
                        description = 'dmv.ca.gov', 
                        logo_url = 'https://content.trinsic.id/connect/integrations/ca-dmv.png', 
                        available = True, 
                        geography = ["CA"], 
                        regions = ["United States"], 
                        launch_method = DeeplinkToMobile, 
                        collection_method = PollResult, 
                        results_may_be_delayed_after_redirect = False, 
                        has_refreshable_content = False, 
                        requires_input = False, 
                        has_trinsic_interface = True, 
                        supports_advanced_provider_sessions = True, 
                        available_fields = [
                            trinsic_api.models.contract_field.ContractField(
                                name = 'person.givenName', 
                                outputted = Always, )
                            ], 
                        sub_providers = [
                            trinsic_api.models.sub_provider_metadata.SubProviderMetadata(
                                id = '', 
                                name = '', 
                                subtext = 'dmv.ca.gov', 
                                description = 'dmv.ca.gov', 
                                logo_url = '', )
                            ], 
                        health = Offline, )
                    ]
            )
        else:
            return ListProviderContractsResponse(
                provider_contracts = [
                    trinsic_api.models.provider_contract.ProviderContract(
                        id = 'usa-california-dmv', 
                        name = 'CA DMV', 
                        subtext = 'dmv.ca.gov', 
                        description = 'dmv.ca.gov', 
                        logo_url = 'https://content.trinsic.id/connect/integrations/ca-dmv.png', 
                        available = True, 
                        geography = ["CA"], 
                        regions = ["United States"], 
                        launch_method = DeeplinkToMobile, 
                        collection_method = PollResult, 
                        results_may_be_delayed_after_redirect = False, 
                        has_refreshable_content = False, 
                        requires_input = False, 
                        has_trinsic_interface = True, 
                        supports_advanced_provider_sessions = True, 
                        available_fields = [
                            trinsic_api.models.contract_field.ContractField(
                                name = 'person.givenName', 
                                outputted = Always, )
                            ], 
                        sub_providers = [
                            trinsic_api.models.sub_provider_metadata.SubProviderMetadata(
                                id = '', 
                                name = '', 
                                subtext = 'dmv.ca.gov', 
                                description = 'dmv.ca.gov', 
                                logo_url = '', )
                            ], 
                        health = Offline, )
                    ],
        )
        """

    def testListProviderContractsResponse(self):
        """Test ListProviderContractsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
