# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.create_widget_session_request import CreateWidgetSessionRequest

class TestCreateWidgetSessionRequest(unittest.TestCase):
    """CreateWidgetSessionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateWidgetSessionRequest:
        """Test CreateWidgetSessionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateWidgetSessionRequest`
        """
        model = CreateWidgetSessionRequest()
        if include_optional:
            return CreateWidgetSessionRequest(
                redirect_url = '',
                providers = [
                    ''
                    ],
                recommendation_info = trinsic_api.models.recommendation_info.RecommendationInfo(
                    phone_number = '', 
                    countries = [
                        ''
                        ], 
                    subdivisions = [
                        ''
                        ], 
                    ip_addresses = [
                        ''
                        ], )
            )
        else:
            return CreateWidgetSessionRequest(
        )
        """

    def testCreateWidgetSessionRequest(self):
        """Test CreateWidgetSessionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
