# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.brazil_digital_cnh_input import BrazilDigitalCnhInput

class TestBrazilDigitalCnhInput(unittest.TestCase):
    """BrazilDigitalCnhInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BrazilDigitalCnhInput:
        """Test BrazilDigitalCnhInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BrazilDigitalCnhInput`
        """
        model = BrazilDigitalCnhInput()
        if include_optional:
            return BrazilDigitalCnhInput(
                cpf_number = '4807288800152802179809012345678910',
                digital_cnh_file = 'YQ==',
                digital_cnh_file_content_type = '',
                facial_biometry_photo = 'YQ=='
            )
        else:
            return BrazilDigitalCnhInput(
                cpf_number = '4807288800152802179809012345678910',
        )
        """

    def testBrazilDigitalCnhInput(self):
        """Test BrazilDigitalCnhInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
