# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.trinsic_test_database_lookup_input import TrinsicTestDatabaseLookupInput

class TestTrinsicTestDatabaseLookupInput(unittest.TestCase):
    """TrinsicTestDatabaseLookupInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TrinsicTestDatabaseLookupInput:
        """Test TrinsicTestDatabaseLookupInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TrinsicTestDatabaseLookupInput`
        """
        model = TrinsicTestDatabaseLookupInput()
        if include_optional:
            return TrinsicTestDatabaseLookupInput(
                given_name = '',
                family_name = '',
                identity_code = '',
                selfie_base64 = ''
            )
        else:
            return TrinsicTestDatabaseLookupInput(
        )
        """

    def testTrinsicTestDatabaseLookupInput(self):
        """Test TrinsicTestDatabaseLookupInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
