# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.create_advanced_provider_session_request import CreateAdvancedProviderSessionRequest

class TestCreateAdvancedProviderSessionRequest(unittest.TestCase):
    """CreateAdvancedProviderSessionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateAdvancedProviderSessionRequest:
        """Test CreateAdvancedProviderSessionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateAdvancedProviderSessionRequest`
        """
        model = CreateAdvancedProviderSessionRequest()
        if include_optional:
            return CreateAdvancedProviderSessionRequest(
                provider = '0',
                redirect_url = '',
                capabilities = [
                    'LaunchBrowser'
                    ],
                fallback_to_hosted_ui = True,
                provider_input = trinsic_api.models.provider_input.ProviderInput(
                    indonesia_nik = null, 
                    mexico_curp = null, 
                    south_africa_nid = null, 
                    kenya_nid = null, 
                    nigeria_nin = null, 
                    aadhaar = null, 
                    bangladesh_national_id = null, 
                    brazil_cpf_check = null, 
                    brazil_digital_cnh = null, 
                    philippine_match = null, 
                    philippine_qr = null, 
                    smart_id = null, 
                    mobile_id = null, 
                    idin = null, 
                    spid = null, 
                    trinsic_test_database_lookup = null, 
                    trinsic_test_sub_providers = null, )
            )
        else:
            return CreateAdvancedProviderSessionRequest(
                provider = '0',
                capabilities = [
                    'LaunchBrowser'
                    ],
        )
        """

    def testCreateAdvancedProviderSessionRequest(self):
        """Test CreateAdvancedProviderSessionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
